@@ -13,22 +13,21 @@ from nb2workflow import nbadapter
 cache = Cache('.nb2workflow/cache')
 enable_cache = False
 
-try:
-    from nb2workflow import logstash
-    logstasher = logstash.LogStasher()    
-except Exception as e:
-    logging.debug("unable to setup logstash %s", repr(e))
-    logstasher = None
+# try:
+#     from nb2workflow import logstash
+#     logstasher = logstash.LogStasher()    
+# except Exception as e:
+#     logging.debug("unable to setup logstash %s", repr(e))
+#     logstasher = None
 
-try:
-    import sentry_sdk
-    sentry_sdk.init(os.environ.get("SENTRY_URI", open("/cdci-resources/sentry-uri").read().strip()))
-except ImportError:
-    sentry_sdk = None
-except Exception as e:
-    import logging
-    logging.debug("big problem with sentry: %s",repr(e))
-    sentry_sdk = None
+# try:
+#     import sentry_sdk
+#     sentry_sdk.init(os.environ.get("SENTRY_URI", open("/cdci-resources/sentry-uri").read().strip()))
+# except ImportError:
+#     sentry_sdk = None
+# except Exception as e:
+#     logging.debug("big problem with sentry: %s",repr(e))
+#     sentry_sdk = None
 
 
 class WorkflowException(Exception):
